View source: R/LHS_strategy_scheme.R
| LHS_strategy_scheme | R Documentation |
This function generates a data frame containing different plant growth strategies based on the Leaf-Height-Seed (LHS) scheme. Each strategy is described by a combination of traits and their corresponding ecological interpretation.
LHS_strategy_scheme()
A data frame with two columns:
Character vector of LHS strategy combinations (e.g., "L-L-L", "L-L-S", etc.)
Character vector describing the ecological strategy for each type
Westoby, M. (1998). A leaf-height-seed (LHS) plant ecology strategy scheme. Plant and Soil, 199, 213–227.
Yang, J., Wang, Z., Zheng, Y., & Pan, Y. (2022). Shifts in plant ecological strategies in remnant forest patches along urbanization gradients. Forest Ecology and Management, 524, 120540.
LHS_strategy_scheme()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.